"use strict";

const express = require("express");
const logger = require("morgan");
const debug = require("debug")("todo:app");

const db = require("./models/db");

db.initDb().then(() => {
    // can't require our model until after the database is initialized
    const { generateTodo } = require("./models/todoModel");

    const apiRouter = require("./routes/api");

    // app represents the whole web application
    const app = express();

    app.use(logger("dev"));

    // tell express to parse JSON from request bodies
    app.use(express.json());

    // registered *middleware* to process static files
    // living in the public directory
    app.use(express.static("public"));

    // add the handler for /api
    app.use('/api', apiRouter);

    // An endpoint is just a different url that the user requested
    app.get('/', (req, res) => {
        // redirect user to the todo page
        res.redirect("/todo.html");
    });

    app.get('/todo.json', (req, res) => {

        let todos = [];
        for (let i = 0; i < 10; i++) {
            todos.push(generateTodo());
        }
        res.json(todos);
    })

    // create a server from this application
    const server = app.listen(3000);
    server.on("listening", () => {
        debug(`Listenting on ${server.address().port}`);
    })
});

