"use strict";
// give access to ToDo items

const { LoremIpsum } = require("lorem-ipsum");
const debug = require("debug")("todo:todo_model");
const sanitize = require("mongo-sanitize");
const { ObjectId } = require("mongodb");

// get default database
const db = require("./db").getDb().db();
// get the collection where we store our data
const collection = db.collection("todos");

const descriptionGenerator = new LoremIpsum({
    sentencesPerParagraph: {
        max: 10,
        min: 4
    },
    wordsPerSentence: {
        max: 16,
        min: 4
    }
});

function getRandomInt(max) {
    return Math.floor(Math.random() * max);
}

function randomDate() {
    const now = new Date();
    return new Date(now.valueOf() + getRandomInt(1000000000));
}

function randomPriority() {
    const priority = ["normal", "high"];
    return priority[getRandomInt(priority.length)];
}


module.exports.generateTodo = () => {
    return {
        desc: descriptionGenerator.generateParagraphs(1),
        priority: randomPriority(),
        due: randomDate()
    };
}

module.exports.insertTodo = async (todo) => {
    // strip out any possibly dangerous data from the document we are about to insert
    todo = sanitize(todo);

    // insert one item into the collection
    const result = await collection.insertOne(todo);

    // result will come back with an "insertedId" field with the _id that was generated by 
    // MongoDB

    // return the todo item with the unique id
    todo._id = result.insertedId;

    return todo;
};

module.exports.getTodo = async (id) => {
    id = sanitize(id);

    const result = await collection.findOne({
        _id: ObjectId(id) // turn ID into an ObjectId object
    });

    return result;
};

module.exports.removeTodo = async (id) => {
    id = sanitize(id);

    // plan ahead to return the object we remove
    const todo = await this.getTodo(id);

    // delete from MongoDB
    const result = await collection.deleteOne({
        _id: ObjectId(id)
    });

    // check if this was deleted
    if (result.deletedCount === 1) {
        return todo;
    } else {
        // did not delete
        throw "No todo with that id";
    }
}

module.exports.getAllTodos = async () => {
    // match everything and convert the cursor (iterator) to an array
    return await collection.find({}).toArray();
}